@@ -5,14 +5,21 @@ import random
 
 def random_emoji(version="latest"):
 
+    dirname = os.path.dirname(__file__)
+
+    try:
+        version = float(version)
+    except ValueError:
+        pass
+
     # Unicode Standard Emoji from
     # https://www.unicode.org/Public/emoji/
 
     try:
-        with open(rf"./emoji/{version}/emoji-test.txt", 'r', encoding='utf-8') as f:
+        with open(os.path.join(dirname, f"./emoji/{version}/emoji-test.txt"), 'r', encoding='utf-8') as f:
             lines = [line for line in f.readlines() if line.strip() and not line.startswith("#")]
-    except:
-        versions = (os.listdir("./emoji"))
+    except FileNotFoundError:
+        versions = (os.listdir(os.path.join(dirname, './emoji')))
         print(f"Unicode version \"{version}\" is not supported. The following versions are currently supported:\n{', '.join(versions)}")
         exit()
 
